@@ -6,8 +6,8 @@ author: Someone someone@example.com
 """
 
 __version__ = "1.0.0"
-__url__ = "https://github.com/zsimic/simple"
-__download_url__ = "https://github.com/zsimic/simple/archive/{version}.tar.gz"
+__url__ = "https://github.com/codrsquad/simple"
+__download_url__ = "https://github.com/codrsquad/simple/archive/{version}.tar.gz"
 
 
 def main():
