@@ -205,7 +205,7 @@ def test_no_extra():
         meta = new_meta("{major}.{minor}.{$FOO}+", scm=conftest.MockGit(True))
         versioning = meta.versioning
         assert meta.version == "0.1.None"
-        assert str(versioning.strategy) == "branch(master):{major}.{minor}.{$FOO}+"
+        assert str(versioning.strategy) == "branch(main,master):{major}.{minor}.{$FOO}+"
         check_render(versioning, "1.0.None")
         check_render(versioning, "1.0.None", distance=2)
         check_render(versioning, "1.0.None", distance=2, dirty=True)
@@ -229,7 +229,7 @@ def test_invalid_part():
         assert "invalid" in str(versioning.strategy.main_bits)
         assert meta.version is None
         assert versioning.problem == "invalid versioning part 'foo'"
-        assert str(versioning.strategy) == "branch(master):{foo}.{major}.{minor}{-function 'extra_version'"
+        assert str(versioning.strategy) == "branch(main,master):{foo}.{major}.{minor}{-function 'extra_version'"
         check_render(versioning, "invalid.1.0")
         check_render(versioning, "invalid.1.0-d2", distance=2)
         check_render(versioning, "invalid.1.0-extra", distance=2, dirty=True)
@@ -247,7 +247,7 @@ def test_invalid_main():
     with conftest.capture_output() as logged:
         meta = new_meta(dict(main=extra_version, extra="", separator=" "), scm=conftest.MockGit())
         versioning = meta.versioning
-        assert str(versioning.strategy) == "branch(master):function 'extra_version' "
+        assert str(versioning.strategy) == "branch(main,master):function 'extra_version' "
         check_render(versioning, "")
         check_render(versioning, "d2", distance=2)
         check_render(versioning, "extra", distance=2, dirty=True)
@@ -275,20 +275,24 @@ def test_distance_marker():
         assert not versioning.problem
         assert not versioning.strategy.problem
         assert meta.version == "0.1.3.dirty"
-        assert str(versioning.strategy) == "branch(master):{major}.{minor}.{distance}{dirty}"
+        assert str(versioning.strategy) == "branch(main,master):{major}.{minor}.{distance}{dirty}"
 
 
 @patch.dict(os.environ, {"BUILD_ID": "543"})
 def test_preconfigured_build_id(*_):
     """Verify that short notations expand to the expected format"""
-    check_preconfigured("branch(master):{major}.{minor}.{patch}{post}{dirty}", "post", "default")
+    check_preconfigured("branch(main,master):{major}.{minor}.{patch}{post}{dirty}", "post", "default")
 
-    check_preconfigured("branch(master):{major}.{minor}.{distance}{dirty}", "distance")
-
-    check_preconfigured("branch(master):{major}.{minor}.{distance}+!h{$*BUILD_ID:local}.{commitid}{dirty}", "build-id", "distance+build-id")
+    check_preconfigured("branch(main,master):{major}.{minor}.{distance}{dirty}", "distance")
 
     check_preconfigured(
-        "branch(master):{major}.{minor}.{patch}{post}+!h{$*BUILD_ID:local}.{commitid}{dirty}",
+        "branch(main,master):{major}.{minor}.{distance}+!h{$*BUILD_ID:local}.{commitid}{dirty}",
+        "build-id",
+        "distance+build-id"
+    )
+
+    check_preconfigured(
+        "branch(main,master):{major}.{minor}.{patch}{post}+!h{$*BUILD_ID:local}.{commitid}{dirty}",
         "+build-id",
         "default+build-id",
         "post+build-id",
@@ -323,7 +327,7 @@ def check_strategy_distance(dirty):
     assert not versioning.strategy.problem
     assert "major" in str(versioning.strategy.main_bits)
     assert "dirty" in str(versioning.strategy.extra_bits)
-    assert str(versioning.strategy) == "branch(master):{major}.{minor}.{distance}{dirty}"
+    assert str(versioning.strategy) == "branch(main,master):{major}.{minor}.{distance}{dirty}"
     if dirty:
         assert meta.version == "0.1.3.dirty"
 
@@ -349,7 +353,7 @@ def check_strategy_build_id(dirty):
     assert not versioning.strategy.problem
     assert "major" in str(versioning.strategy.main_bits)
     assert "commitid" in str(versioning.strategy.extra_bits)
-    assert str(versioning.strategy) == "branch(master):{major}.{minor}.{distance}+!h{$*BUILD_ID:local}.{commitid}{dirty}"
+    assert str(versioning.strategy) == "branch(main,master):{major}.{minor}.{distance}+!h{$*BUILD_ID:local}.{commitid}{dirty}"
     if dirty:
         assert meta.version == "0.1.3+h543.g123.dirty"
 
@@ -437,6 +441,15 @@ def test_brand_new_project():
 
 
 def test_git_versioning(sample_project):
+    output = setupmeta.run_program(sys.executable, "setup.py", "--version", capture=True)
+    assert output == "0.0.1"
+
+    # Bump with no initial tags shouldn't warn
+    output = setupmeta.run_program(sys.executable, "setup.py", "version", "--bump", "minor", capture="all")
+    assert "UserWarning" not in output
+    assert "Would run: git tag -a v0.1.0" in output
+
+    conftest.run_git("tag", "-a", "v0.1.0", "-m", "Version 2.4.2")
     output = setupmeta.run_program(sys.executable, "setup.py", "--version", capture=True)
     assert output == "0.1.0"
 
